<?php


class nodeaspect_PageInfo {

  protected $info;

  function __construct(array $info) {
    $this->info = $info;
  }

  function localTaskWeight() {
    return $this->info['tab'] ? @$this->info['weight'] : FALSE;
  }

  /**
   * Access callback.
   * This only returns an internal variable.
   */
  function access() {
    return !empty($this->info['access']);
  }

  /**
   * Title callback.
   * This only returns an internal variable.
   */
  function title() {
    return $this->info['title'];
  }

  /**
   * Page callback.
   */
  function page($node) {

    if (!empty($this->info['page_title'])) {
      drupal_set_title($this->info['page_title']);
    }

    if (isset($this->info['view_mode'])) {
      return $this->_nodeShow($node);
    }
    elseif (isset($this->info['page callback'])) {
      if (!empty($this->info['file'])) {
        require_once $this->info['file'];
      }
      return call_user_func_array($this->info['page callback'], $this->info['page arguments']);
    }
    elseif (isset($this->info['redirect'])) {
      // TODO: drupal_goto().
    }
  }

  function hook_pageapi($api, $node, $suffix) {
    if (!empty($this->info['pageapi_callback'])) {
      $f = $this->info['pageapi_callback'];
      $api->setModule($this->info['module']);
      if (empty($this->info['pageapi_arguments'])) {
        $f($api, $node, $suffix);
      }
      else {
        $args = array_merge(array($api, $node, $suffix), $this->info['pageapi_arguments']);
        call_user_func_array($f, $args);
      }
    }
  }

  /**
   * Adapted from function node_show()
   */
  protected function _nodeShow($node) {

    $info = $this->info;
    $node->build_mode = $info['view_mode'];
    $output = node_view($node, $info['render as teaser'], $info['render as page'], $info['render links']);

    if (!isset($info['render comments'])) {
      $info['render comments'] = $node->comment;
    }

    if (function_exists('comment_render') && $node->comment && $info['render comments']) {
      $output .= comment_render($node);
    }

    // Update the history table, stating that this user viewed this node.
    node_tag_new($node->nid);

    return $output;
  }
}
